migrations

package
v1.5.50 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 2, 2026 License: Apache-2.0 Imports: 6 Imported by: 2

Documentation

Overview

Package migrations holds PostgreSQL migrations for databases to back `datastore` implementations.

Index

Constants

This section is empty.

Variables

var (
	IndexerMigrationTable = pgx.Identifier{"libindex_migrations"}
	MatcherMigrationTable = pgx.Identifier{"libvuln_migrations"}
)

These are the tables used to track migrations.

Deprecated: use the Indexer and Matcher functions.

Functions

func Indexer added in v1.5.50

func Indexer(ctx context.Context, cfg *pgx.ConnConfig) error

Indexer runs migrations for an indexer database using the provided configuration.

func Matcher added in v1.5.50

func Matcher(ctx context.Context, cfg *pgx.ConnConfig) error

Matcher runs migrations for a matcher database using the provided configuration.

Types

This section is empty.

Jump to